;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "clojure-mode" "20260325.811"
  "Major mode for Clojure code."
  '((emacs "27.1"))
  :url "https://github.com/clojure-emacs/clojure-mode"
  :commit "9146525680b29a0c6b72a1126d075b54f8066710"
  :revdesc "9146525680b2"
  :keywords '("languages" "clojure" "clojurescript" "lisp")
  :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
